@@ -21,24 +21,25 @@
 #
 # ---------------------------------------------------------------------------
 
-# imports
+import formatter
+import htmllib
 import os
 import sys
-import htmllib
-import formatter
 import traceback
-from pysollib.mygettext import _
+
+import gobject
 
 import gtk
-import pango
-import gobject
 from gtk import gdk
 
-# PySol imports
+import pango
+
 from pysollib.mfxutil import Struct, openURL
+from pysollib.mygettext import _
 from pysollib.settings import TITLE
 
-# Toolkit imports
+import six
+
 from tkwidget import MfxMessageDialog
 
 if __name__ == '__main__':
@@ -47,9 +48,6 @@ if __name__ == '__main__':
     import gettext
     gettext.install('pysol', d, unicode=True)
 
-if sys.version_info > (3,):
-    unicode = str
-
 REMOTE_PROTOCOLS = ('ftp:', 'gopher:', 'http:', 'mailto:', 'news:', 'telnet:')
 
 
@@ -72,7 +70,7 @@ class tkHTMLWriter(formatter.NullWriter):
         self.indent = ''
 
     def write(self, data):
-        data = unicode(data)
+        data = six.text_type(data)
         self.text.insert(self.text.get_end_iter(), data, len(data))
 
     def anchor_bgn(self, href, name, type):
