@@ -21,16 +21,11 @@
 #
 # ---------------------------------------------------------------------------##
 
-# imports
-
-# PySol imports
-from pysollib.gamedb import registerGame, GameInfo, GI
 from pysollib.game import Game
-from pysollib.layout import Layout
-
+from pysollib.gamedb import GI, GameInfo, registerGame
 from pysollib.games.gypsy import \
         DieKoenigsbergerin_Talon, DieRussische_Foundation
-
+from pysollib.layout import Layout
 from pysollib.stack import AC_RowStack
 
 # ************************************************************************
