@@ -21,24 +21,19 @@
 #
 # ---------------------------------------------------------------------------##
 
-# imports
-import sys
 import os
+import sys
 import traceback
 
-# PySol imports
-from pysollib.mfxutil import print_err
-from pysollib.resource import CSI
-from pysollib.configobj import configobj, validate
+
 import pysollib.settings
-
-# Toolkit imports
-from pysollib.pysoltk import TOOLBAR_BUTTONS, TOOLKIT
-
+from pysollib.configobj import configobj, validate
+from pysollib.mfxutil import print_err
 from pysollib.mygettext import _
+from pysollib.pysoltk import TOOLBAR_BUTTONS, TOOLKIT
+from pysollib.resource import CSI
 
-if sys.version_info > (3,):
-    unicode = str
+import six
 
 # ************************************************************************
 # * Options
@@ -113,6 +108,8 @@ translate_game_names = boolean
 solver_presets = string_list
 solver_show_progress = boolean
 solver_max_iterations = integer
+solver_iterations_output_step = integer
+solver_preset = string
 display_win_message = boolean
 
 [sound_samples]
@@ -249,6 +246,8 @@ class Options:
         ('solver_presets', 'list'),
         ('solver_show_progress', 'bool'),
         ('solver_max_iterations', 'int'),
+        ('solver_iterations_output_step', 'int'),
+        ('solver_preset', 'string'),
         # ('toolbar_vars', 'list'),
         # ('recent_gameid', 'list'),
         # ('favorite_gameid', 'list'),
@@ -422,6 +421,7 @@ class Options:
             'good-intentions',
             'hello-world',
             'john-galt-line',
+            'looking-glass',
             'one-big-family',
             'rin-tin-tin',
             'slick-rock',
@@ -431,6 +431,8 @@ class Options:
             ]
         self.solver_show_progress = True
         self.solver_max_iterations = 100000
+        self.solver_iterations_output_step = 100
+        self.solver_preset = 'video-editing'
 
     def setDefaults(self, top=None):
         WIN_SYSTEM = pysollib.settings.WIN_SYSTEM
@@ -512,7 +514,7 @@ class Options:
             val = getattr(self, key)
             if isinstance(val, str):
                 if sys.version_info < (3,):
-                    val = unicode(val, 'utf-8')
+                    val = six.text_type(val, 'utf-8')
             config['general'][key] = val
 
         config['general']['recent_gameid'] = self.recent_gameid
