@@ -21,23 +21,24 @@
 #
 # ---------------------------------------------------------------------------##
 
-
-# imports
 import os
-import gtk
+
 import gobject
 
-# PySol imports
+import gtk
+
+from pysollib.mfxutil import kwdefault
 from pysollib.mygettext import _
 from pysollib.resource import CSI
-from pysollib.mfxutil import kwdefault
 
-# Toolkit imports
-from tkwidget import MfxDialog
 from pysoltree import PysolTreeView
+
 from tkcanvas import MfxCanvas, MfxCanvasImage
+
 from tkutil import loadImage
 
+from tkwidget import MfxDialog
+
 
 # ************************************************************************
 # * Dialog
@@ -214,11 +215,11 @@ class SelectCardsetDialogWithPreview(MfxDialog):
         for image in self.preview_images:
             MfxCanvasImage(canvas, x, y, anchor="nw", image=image)
             sx, sy = max(x, sx), max(y, sy)
-            i = i + 1
+            i += 1
             if i % columns == 0:
                 x, y = 10, y + dy
             else:
-                x = x + dx
+                x += dx
         canvas.config(width=sx+dx, height=sy+dy)
         canvas.set_scroll_region(0, 0, sx+dx, sy+dy)
         self.preview_key = key
