@@ -22,19 +22,13 @@
 # ---------------------------------------------------------------------------##
 
 
-# imports
 import os
 
-# settings
-from pysollib.settings import TOOLKIT
-
-# PySol imports
-from pysollib.resource import CSI
 from pysollib.mfxutil import Image, ImageTk, USE_PIL
-
-# Toolkit imports
-from pysollib.pysoltk import loadImage, copyImage, createImage, \
-        shadowImage, createBottom
+from pysollib.pysoltk import copyImage, createBottom, createImage, loadImage
+from pysollib.pysoltk import shadowImage
+from pysollib.resource import CSI
+from pysollib.settings import TOOLKIT
 
 # ************************************************************************
 # * Images
@@ -86,6 +80,7 @@ class Images:
         # print '__loadCard:', filename
         f = os.path.join(self.cs.dir, filename)
         if not os.path.exists(f):
+            print('card image path %s does not exist' % (f))
             return None
         try:
             img = loadImage(file=f)
@@ -114,10 +109,10 @@ class Images:
             imagedir = self.d.findDir(cs_type, d)
         except Exception:
             pass
-        if not USE_PIL or imagedir is None:
+        if (not USE_PIL and TOOLKIT != 'kivy') or imagedir is None:
             # load image
             img = self.__loadCard(filename+self.cs.ext, check_w, check_h)
-            if USE_PIL:
+            if USE_PIL and img is not None:
                 # we have no bottom images
                 # (data/images/cards/bottoms/<cs_type>)
                 img = img.resize(self._xfactor, self._yfactor)
@@ -148,11 +143,11 @@ class Images:
         # bottoms / letters
         bottom = None
         neg_bottom = None
-        while len(self._bottom_positive) < 7:
+        while len(self._bottom_positive) < max(7, self.cs.nbottoms):
             if bottom is None:
                 bottom = createImage(cw, ch, fill=None, outline="#000000")
             self._bottom_positive.append(bottom)
-        while len(self._bottom_negative) < 7:
+        while len(self._bottom_negative) < max(7, self.cs.nbottoms):
             if neg_bottom is None:
                 neg_bottom = createImage(cw, ch, fill=None, outline="#ffffff")
             self._bottom_negative.append(neg_bottom)
@@ -191,14 +186,16 @@ class Images:
         # load bottoms
         for i in range(self.cs.nbottoms):
             name = "bottom%02d" % (i + 1)
-            self._bottom_positive.append(
-                self.__loadBottom(name, color='black'))
+            bottom = self.__loadBottom(name, color='black')
+            if bottom is not None:
+                self._bottom_positive.append(bottom)
             if progress:
                 progress.update(step=pstep)
             # load negative bottoms
             name = "bottom%02d-n" % (i + 1)
-            self._bottom_negative.append(
-                self.__loadBottom(name, color='white'))
+            bottom = self.__loadBottom(name, color='white')
+            if bottom is not None:
+                self._bottom_negative.append(bottom)
             if progress:
                 progress.update(step=pstep)
         # load letters
@@ -260,6 +257,8 @@ class Images:
         return self._bottom[0]
 
     def getBlankBottom(self):
+        if TOOLKIT == 'kivy':
+            return self._bottom[0]
         return self._blank_bottom
 
     def getSuitBottom(self, suit=-1):
@@ -433,11 +432,13 @@ class Images:
         self._bottom_positive = []
         for i in range(self.cs.nbottoms):
             name = "bottom%02d" % (i + 1)
-            self._bottom_positive.append(
-                self.__loadBottom(name, color='black'))
+            bottom = self.__loadBottom(name, color='black')
+            if bottom is not None:
+                self._bottom_positive.append(bottom)
             name = "bottom%02d-n" % (i + 1)
-            self._bottom_negative.append(
-                self.__loadBottom(name, color='white'))
+            bottom = self.__loadBottom(name, color='white')
+            if bottom is not None:
+                self._bottom_negative.append(bottom)
         # letters
         self._letter_positive = []
         self._letter_negative = []
