@@ -21,54 +21,36 @@
 
 from __future__ import division
 
-# import os
-# print ('KIVY_HOME: '+os.environ['KIVY_HOME'])
-
 import logging
-# import time
 import math
 import traceback
 
-from kivy.graphics import Color
-from kivy.graphics import Rectangle
-from kivy.graphics import Line
-from kivy.graphics import Triangle
-
-# from kivy.uix.treeview import TreeView
-# from kivy.uix.actionbar import ActionBar
-from kivy.utils import platform
-# from kivy.event import EventDispatcher
-
-from kivy.properties import StringProperty
-
-from kivy.base import EventLoop
-# from kivy.base import EventLoopBase
-from kivy.base import stopTouchApp
-from kivy.app import App
 from kivy.animation import Animation
-from kivy.core.audio import SoundLoader
+from kivy.app import App
+from kivy.base import EventLoop
+from kivy.base import stopTouchApp
+from kivy.cache import Cache
 from kivy.clock import Clock
-
-from kivy.uix.image import Image as KivyImage
-# from kivy.uix.anchorlayout import AnchorLayout
-from kivy.uix.boxlayout import BoxLayout
-from kivy.uix.widget import Widget
-from kivy.uix.button import Button
-from kivy.uix.behaviors import ButtonBehavior
-from kivy.uix.label import Label
-# from kivy.uix.relativelayout import RelativeLayout
-from kivy.uix.scrollview import ScrollView
-
-from kivy.uix.actionbar import ActionView
-from kivy.uix.actionbar import ActionPrevious
+from kivy.core.audio import SoundLoader
+from kivy.core.window import Window
+from kivy.graphics import Color
+from kivy.graphics import Line
+from kivy.graphics import Rectangle
+from kivy.graphics import Triangle
+from kivy.properties import StringProperty
 from kivy.uix.actionbar import ActionButton
-
+from kivy.uix.actionbar import ActionPrevious
+from kivy.uix.actionbar import ActionView
+from kivy.uix.behaviors import ButtonBehavior
+from kivy.uix.boxlayout import BoxLayout
+from kivy.uix.button import Button
+from kivy.uix.image import Image as KivyImage
+from kivy.uix.label import Label
+from kivy.uix.scrollview import ScrollView
 from kivy.uix.treeview import TreeView
 from kivy.uix.treeview import TreeViewLabel
-
-from kivy.core.window import Window
-from kivy.cache import Cache
-
+from kivy.uix.widget import Widget
+from kivy.utils import platform
 
 # =============================================================================
 
@@ -79,6 +61,62 @@ def get_platform():
 # =============================================================================
 
 
+def get_screen_ori():
+    if get_platform() == 'android':
+        from jnius import autoclass
+        from jnius import cast
+    else:
+        logging.info("LApp: ori = unknown")
+        return None
+
+    PythonActivity = autoclass('org.kivy.android.PythonActivity')
+    currentActivity = cast('android.app.Activity', PythonActivity.mActivity)
+
+    # Display = autoclass('android.view.Display')
+    # WindowManager = autoclass('android.view.WindowManager')
+
+    wm = currentActivity.getWindowManager()
+    d = wm.getDefaultDisplay()
+
+    so = None
+    if d.getWidth() > d.getHeight():
+        so = 'landscape'
+    else:
+        so = 'portrait'
+
+    logging.info("LApp: ori = %s" % so)
+    return so
+
+# =============================================================================
+# kivy EventDispatcher passes keywords, that to not correspond to properties
+# to the base classes. Finally they will reach 'object'. With python3 (but not
+# python2) 'object' throws an exception 'takes no parameters' in that a
+# situation. We therefore underlay a base class (right outside), which
+# swallows up remaining keywords. Thus the keywords do not reach 'object' any
+# more.
+
+
+class LBase(object):
+    def __init__(self, **kw):
+        super(LBase, self).__init__()
+
+# =============================================================================
+
+
+class LPopCommander(LBase):
+    def __init__(self, **kw):
+        super(LPopCommander, self).__init__()
+        self.pop_command = kw['pop_command']
+
+    def pop(self):
+        if self.pop_command is not None:
+            self.pop_command(0)
+            return True
+        return False
+
+# =============================================================================
+
+
 class LAnimationMgr(object):
     def __init__(self, **kw):
         super(LAnimationMgr, self).__init__()
@@ -157,7 +195,7 @@ LSoundLoader = SoundLoader
 # =============================================================================
 
 
-class LBoxLayout(BoxLayout):
+class LBoxLayout(BoxLayout, LBase):
     def __init__(self, **kw):
         super(LBoxLayout, self).__init__(**kw)
 
@@ -170,7 +208,7 @@ class LBoxLayout(BoxLayout):
 # =============================================================================
 
 
-class LImage(KivyImage):
+class LImage(KivyImage, LBase):
 
     def __init__(self, **kwargs):
         super(LImage, self).__init__(**kwargs)
@@ -289,11 +327,12 @@ def LColorToKivy(outline):
 # =============================================================================
 
 
-class LText(Widget):
+class LText(Widget, LBase):
     text = StringProperty('')
 
     def __init__(self, canvas, x, y, **kwargs):
         super(LText, self).__init__(**kwargs)
+        # super(LText, self).__init__()
 
         if 'text' not in kwargs:
             kwargs['text'] = 'X'
@@ -316,7 +355,13 @@ class LText(Widget):
         # print('LText: font = %s, font_size = %s' % (font, fontsize))
         # print('LText: text = %s' % (self.text))
 
-        self.label = Label(font=font, font_size=fontsize, **kwargs)
+        kwargs['font'] = font
+        kwargs['font_size'] = fontsize
+
+        class MyLabel(Label, LBase):
+            pass
+
+        self.label = MyLabel(**kwargs)
         self.label.texture_update()
         self.coreSize = self.label.texture_size
         self.corePos = (x, y)
@@ -363,7 +408,7 @@ class LEvent(object):
 # =============================================================================
 
 
-class LLine(Widget):
+class LLine(Widget, LBase):
     def __init__(self, canvas, args, **kw):
         super(LLine, self).__init__(**kw)
 
@@ -536,7 +581,7 @@ class LLine(Widget):
 # =============================================================================
 
 
-class LRectangle(Widget):
+class LRectangle(Widget, LBase):
     def __init__(self, prnt, args, **kw):
         super(LRectangle, self).__init__(**kw)
         self.prnt = prnt
@@ -647,7 +692,7 @@ class LRectangle(Widget):
 # =============================================================================
 
 
-class LImageItem(BoxLayout):
+class LImageItem(BoxLayout, LBase):
     def __init__(self, **kw):
         super(LImageItem, self).__init__(**kw)
         self.game = None
@@ -717,7 +762,7 @@ class LImageItem(BoxLayout):
 
     def on_touch_up(self, touch):
         if touch.grab_current is self:
-                # release my grabbed touch!
+            # release my grabbed touch!
             print('ungrab')
             touch.ungrab(self)
             return True
@@ -789,13 +834,28 @@ class LImageItem(BoxLayout):
 # Treeview
 
 
-class LTreeRoot(TreeView):
+class LTreeRoot(TreeView, LBase):
     def __init__(self, **kw):
         super(LTreeRoot, self).__init__(**kw)
         self.kw = kw
 
+    def closeLastNode(self):
+        ret = False
+        lastopen = None
+        for ti in reversed(self.children):
+            if isinstance(ti, LTreeNode):
+                if ti.is_open:
+                    lastopen = ti
 
-class LTreeNode(ButtonBehavior, TreeViewLabel):
+        if lastopen is not None:
+            self.toggle_node(lastopen)
+            self.select_node(lastopen)
+            ret = True
+
+        return ret
+
+
+class LTreeNode(ButtonBehavior, TreeViewLabel, LBase):
 
     # def __init__(self, gameview, **kw):
     def __init__(self, **kw):
@@ -950,7 +1010,7 @@ class LTreeNode(ButtonBehavior, TreeViewLabel):
 # =============================================================================
 
 
-class LTopLevelContent(BoxLayout):
+class LTopLevelContent(BoxLayout, LBase):
     def __init__(self, **kw):
         super(LTopLevelContent, self).__init__(**kw)
 
@@ -971,7 +1031,7 @@ class LTopLevelContent(BoxLayout):
 # =============================================================================
 
 
-class LTopLine(ButtonBehavior, Label):
+class LTopLine(ButtonBehavior, Label, LBase):
 
     def __init__(self, **kw):
         super(LTopLine, self).__init__(**kw)
@@ -994,10 +1054,11 @@ class LTopLine(ButtonBehavior, Label):
 # =============================================================================
 
 
-class LTopLevel0(BoxLayout):
+class LTopLevel0(BoxLayout, LBase):
     def __init__(self, top, title=None, **kw):
         self.main = top
-        super(LTopLevel0, self).__init__(orientation="vertical", **kw)
+        super(LTopLevel0, self).__init__(
+            orientation="vertical", **kw)
 
         # self.canvas.add(Color(0, 1, 0, 0.4))
         # self.canvas.add(Rectangle(pos=(100, 100), size=(100, 100)))
@@ -1033,10 +1094,11 @@ class LTopLevel0(BoxLayout):
 # =============================================================================
 
 
-class LTopLevel(BoxLayout):
+class LTopLevel(BoxLayout, LBase):
     def __init__(self, parent, title=None, **kw):
         self.mainwindow = parent
-        super(LTopLevel, self).__init__(orientation="vertical", **kw)
+        super(LTopLevel, self).__init__(
+            orientation="vertical", **kw)
 
         if ('size_hint' not in kw):
             self.size_hint = (0.5, 1.0)
@@ -1048,12 +1110,31 @@ class LTopLevel(BoxLayout):
         self.add_widget(self.titleline)
         self.add_widget(self.content)
 
+    def processAndroidBack(self):
+        ret = False
+        # try to collapse the last open tree node
+        # the treeview will be located inside of a scrollview
+        # (-> menubar.py)
+        for c in self.content.children:
+            # print("childitem: %s" % str(c))
+            if isinstance(c, LScrollView):
+                for t in reversed(c.children):
+                    # print("  childitem: %s" % str(t))
+                    if isinstance(t, LTreeRoot):
+                        ret = t.closeLastNode()
+            if isinstance(c, BoxLayout):
+                for t in reversed(c.children):
+                    # print("  childitem: %s" % str(t))
+                    if isinstance(t, LPopCommander):
+                        ret = t.pop()
+                    pass
+        return ret
+
+
 # =============================================================================
 
-# class LMenuBar(ActionBar):
 
-
-class LMenuBar(BoxLayout):
+class LMenuBar(BoxLayout, LBase):
     def __init__(self, **kw):
         super(LMenuBar, self).__init__(**kw)
         self.menu = None
@@ -1080,13 +1161,18 @@ class LMenuBar(BoxLayout):
 # =============================================================================
 
 
-class LMenu(ActionView):
+class LMenu(ActionView, LBase):
     def __init__(self, prev, **kw):
         super(LMenu, self).__init__(**kw)
-        self.ap = ap = ActionPrevious(
-            with_previous=prev, size_hint=(.01, 1), **kw)
-        ap.app_icon = 'data/images/misc/pysol01.png'
-        self.add_widget(ap)
+
+        class MyActionPrev(ActionPrevious, LBase):
+            pass
+
+        kw['app_icon'] = 'data/images/misc/pysol01.png'
+        kw['with_previous'] = prev
+        kw['size_hint'] = (.01, 1)
+        self.ap = MyActionPrev(**kw)
+        self.add_widget(self.ap)
         self.bar = None
         self.uppermenu = None
 
@@ -1126,7 +1212,7 @@ class LMenu(ActionView):
                 pass
 
         for c in items:
-                # print ('LMenu: delete child %s' % c)
+            # print ('LMenu: delete child %s' % c)
             self.clear_widgets([c])
         for c in menues:
             # print ('LMenu: delete child %s' % c)
@@ -1139,10 +1225,11 @@ class LMenu(ActionView):
 # =============================================================================
 
 
-class LMenuItem(ActionButton):
+class LMenuItem(ActionButton, LBase):
 
     def __init__(self, menu, **kw):
         super(LMenuItem, self).__init__(**kw)
+        # super(LMenuItem, self).__init__()
         self.bar = None
         self.submenu = None
         self.menu = menu
@@ -1182,7 +1269,7 @@ class LMenuItem(ActionButton):
 # =============================================================================
 
 
-class LScrollView(ScrollView):
+class LScrollView(ScrollView, LBase):
     def __init__(self, **kw):
         super(LScrollView, self).__init__(**kw)
         self.delayDown = False
@@ -1244,6 +1331,7 @@ class LTkBase:
         logging.info("LTkBase: __init__()")
         self.sleeping = False
         self.in_loop = False
+        self.screenSize = (1000, 1000)
 
     def cget(self, strg):
         return False
@@ -1259,6 +1347,22 @@ class LTkBase:
         self.icontitle = strg
         logging.info("LTkBase: wm_iconname %s" % strg)
 
+    def eval_screen_dim(self, size):
+        self.screenSize = size
+        if get_platform() == 'android':
+            from jnius import autoclass
+            from jnius import cast
+        else:
+            return
+
+        PythonActivity = autoclass('org.kivy.android.PythonActivity')
+        currentActivity = cast(
+            'android.app.Activity', PythonActivity.mActivity)
+        wm = currentActivity.getWindowManager()
+        d = wm.getDefaultDisplay()
+
+        self.screenSize = (d.getWidth(), d.getHeight())
+
     def winfo_screenwidth(self):
         logging.info("LTkBase: winfo_screenwidth %s" % str(self.size[0]))
         return self.size[0]
@@ -1362,6 +1466,9 @@ class LTkBase:
             self.in_loop = False
         logging.info('LTkBase: wait condition end')
 
+    def waitAnimation(self):
+        self.waitCondition(LAnimationManager.checkRunning)
+
     def tkraise(self):
         pass
 
@@ -1422,13 +1529,8 @@ class LMainWindow(BoxLayout, LTkBase):
             background_normal='atlas:'
                               '//data/images/defaulttheme/action_item',
             border=(0, 0, 0, 0))
-        self.topLine1 = Label(
-            size_hint=(1.0, 0.01),
-            background_down='atlas:'
-                            '//data/images/defaulttheme/action_item_down',
-            background_normal='atlas:'
-                              '//data/images/defaulttheme/action_item',
-            border=(0, 0, 0, 0))
+        self.topLine1 = Label(size_hint=(1.0, 0.01))
+
         self.add_widget(self.topLine)
         self.add_widget(self.menuArea)
         self.add_widget(self.topLine1)
@@ -1439,6 +1541,8 @@ class LMainWindow(BoxLayout, LTkBase):
         self.workStack = LStack()
         self.app = None
 
+        # self.touches = []
+
         # beispiel zu canvas (hintergrund)
         # with self.canvas.before:
         #   Color(0, 1, 0.7, 0.5)
@@ -1450,11 +1554,42 @@ class LMainWindow(BoxLayout, LTkBase):
     #   self.rect.pos = self.pos
     #   self.rect.size = self.size
 
+    def on_motion(self, m):
+        print('on_motion', m)
+        pass
+
     # Events.
 
     def on_touch_down(self, touch):
         ret = False
 
+        # print(dir(touch))
+
+        # multitouch detection
+        '''
+        #print("MainWindow touch_down",touch.ox,touch.oy)
+        #print("MainWindow touch_down",touch.sx,touch.sy)
+        #print("MainWindow touch_down",touch.px,touch.py)
+        self.touches.append(touch)
+        print("touches cnt = ",len(self.touches))
+        '''
+        # multiclick detection
+        '''
+        if touch.is_double_tap:
+            # print('Touch is a double tap !')
+            # print(' - interval is', touch.double_tap_time)
+            # print(' - distance betw. previous is', touch.double_tap_distance)
+            # test the functions of Android back key
+            ret = self.processAndroidBack()
+            if (ret):
+                return ret
+        '''
+        '''
+        if touch.is_triple_tap:
+            print('Touch is a triple tap !')
+            print(' - interval is', touch.triple_tap_time)
+            print(' - distance between previous is', touch.triple_tap_distance)
+        '''
         # (Eventloop reentrancy check)
         if self.in_loop:
             return ret
@@ -1483,6 +1618,12 @@ class LMainWindow(BoxLayout, LTkBase):
             ret = c.on_touch_up(touch)
             if ret:
                 break
+
+        # multitouch support
+        '''
+        self.touches = [xx for xx in self.touches if xx != touch]
+        print("touches cnt = ",len(self.touches))
+        '''
         return ret
 
     # Menubar:
@@ -1503,19 +1644,23 @@ class LMainWindow(BoxLayout, LTkBase):
 
     # Workarea:
 
-    def rebuildContainer(self):
+    def removeContainer(self):
         self.workContainer.clear_widgets()
         self.workContainerO.clear_widgets()
 
+    def buildContainer(self):
         if self.toolBar is not None and self.toolBarPos == 3:
             self.workContainerO.add_widget(self.toolBar)
         self.workContainerO.add_widget(self.workContainer)
         if self.toolBar is not None and self.toolBarPos == 4:
             self.workContainerO.add_widget(self.toolBar)
-
         for w in self.workStack.items:
             self.workContainer.add_widget(w[1])
 
+    def rebuildContainer(self):
+        self.removeContainer()
+        self.buildContainer()
+
     def pushWork(self, key, widget):
         if (widget):
             self.workStack.push(key, widget)
@@ -1534,6 +1679,27 @@ class LMainWindow(BoxLayout, LTkBase):
     def getWork(self, key):
         return self.workStack.peek(key)
 
+    def processAndroidBack(self):
+        ret = False
+        # try to close currently open popup windows, one by one
+        r = range(len(self.workStack.items))
+        rr = reversed(r)
+        for i in rr:
+            t = self.workStack.items[i]
+            # print("stackkey:  %s" % str(t[0]))
+            # print("stackitem: %s" % str(t[1]))
+            if t[0] == 'playground':
+                pass
+            else:
+                if isinstance(t[1], LTopLevel):
+                    ret = t[1].processAndroidBack()
+                if not ret:
+                    self.popWork(t[0])
+                    ret = True
+            if ret:
+                break
+        return ret
+
 # =============================================================================
 
 
@@ -1548,7 +1714,12 @@ class LApp(App):
             if app is None:
                 return False  # delegate
 
-            # redirect to game undo last step
+            # redirect to mainwindow to close popups, tree nodes
+            # and html pages.
+            if (self.mainWindow.processAndroidBack()):
+                return True  # consumed
+
+            # redirect to game to undo last step
             app.menubar.mUndo()
             return True     # consumed
         else:
@@ -1556,6 +1727,9 @@ class LApp(App):
 
     def __init__(self):
         super(LApp, self).__init__()
+
+        # Config.set('input', 'multitouchscreen1', 'tuio,0.0.0.0:3333')
+
         self.mainWindow = LMainWindow()
         logging.info('top = %s' % str(self.mainWindow))
         Cache.register('LAppCache', limit=10)
@@ -1571,11 +1745,7 @@ class LApp(App):
     # es nötig wäre).
     # Update:
     # Nachdem im Manifest nun steht 'configChange=...|screenSize' bekommen
-    # wir auch nach dem on_resume ein Signal. Zum Update rufen wir
-    # rebuildContainer verzögert auf. Aus unerfindlichen Gründen ist es
-    # jedoch notwendig die Verzögerung 2-stufig zu organisieren. Der erste
-    # Delay wird offensichtlich unter gegebenen Umständen ignoriert.
-    # LB170517.
+    # wir auch nach dem on_resume ein Signal.
 
     def delayedRebuild(self, dt):
         logging.info("LApp: delayedRebuild")
@@ -1583,7 +1753,8 @@ class LApp(App):
 
     def makeDelayedRebuild(self):
         def delayedRebuild(dt):
-            Clock.schedule_once(self.delayedRebuild, 0.01)
+            # Clock.schedule_once(self.delayedRebuild, 0.01)
+            Clock.schedule_once(self.delayedRebuild, 0.5)
         return delayedRebuild
 
     def doSize(self, obj, val):
@@ -1591,6 +1762,7 @@ class LApp(App):
         logging.info("LApp: size changed %s - %s (%s)" % (obj, val, mval))
         # Clock.schedule_once(self.delayedRebuild, 0.01)
         Clock.schedule_once(self.makeDelayedRebuild(), 0.01)
+        # self.mainWindow.rebuildContainer()
         pass
 
     def on_start(self):
@@ -1680,14 +1852,19 @@ class LApp(App):
         if app is None:
             return
 
+        so = get_screen_ori()
+        go = so  # flake8: F841 nonsense!
+        so = go
         logging.info("LApp: on_resume, Window.size=%s" % str(Window.size))
         # ANM:
-        # Nicht einmal das Basiswindow wird hier über eine
-        # Orientierungsänderung informiert, die während der Pause eintrat.
-        # Eine korrekte Darstellung kann daher nicht garantiert werden.
-        # Wenn die sensoren ev. später für eine korrektur sorgen, erfolgt
-        # ebenfalls kein update, weil sich die parameter am Basiswindow ja
-        # zum alten bekannten Wert hin ändern (also gar nicht).
+        # kivy.core.window.Window hat hier u.U. eine falsche dimension
+        # und unterscheidet sich vom display (-> in get_screen_ori).
+        # Eine korrektur der Parameter von Window kann hier wie skizziert
+        # durchgeführt werden und führt auch zu den korrekten 'on_size'
+        # Notifikationen. Allerdings wird später (nach diesem Aufruf)
+        # eine weitere Notifikation erhalten, welche das Fenster u.U.
+        # wieder falsch aufstellt. (woher kommt die und warum ist sie
+        # oft falsch ?)
 
         if app.game.pause:
             Clock.schedule_once(self.makeEndPauseCmd(app), 3.0)
