@@ -22,69 +22,37 @@
 #
 # ---------------------------------------------------------------------------#
 
-# imports
 import math
 import os
-# import sys
 import re
-# import logging
-# import traceback
 
-# PySol imports
-# from pysollib.mygettext import _, n_
-from pysollib.mygettext import _
-# from pysollib.mfxutil import Struct, kwdefault
-from pysollib.mfxutil import Struct
-# from pysollib.mfxutil import Image
-from pysollib.util import CARDSET
-# from pysollib.settings import TITLE, WIN_SYSTEM
-from pysollib.settings import TITLE
-# from pysollib.settings import TOP_TITLE
-from pysollib.settings import SELECT_GAME_MENU
-# from pysollib.settings import USE_FREECELL_SOLVER
-# from pysollib.settings import DEBUG
-from pysollib.gamedb import GI
-# from pysollib.pysoltk import MfxMenu
-# from pysollib.pysoltk import SelectCardsetDialogWithPreview
-
-# toolkit imports
-from pysollib.kivy.tkconst import EVENT_HANDLED, EVENT_PROPAGATE, CURSOR_WATCH
-from pysollib.kivy.tkutil import bind
-from pysollib.kivy.tkutil import after_idle
-from pysollib.kivy.selectcardset import SelectCardsetDialogWithPreview
-
-from selectgame import SelectGameDialog
-from findcarddialog import connect_game_find_card_dialog
-from findcarddialog import destroy_find_card_dialog
-from solverdialog import connect_game_solver_dialog
-from tkconst import TOOLBAR_BUTTONS
-
-# Kivy
-
-# from kivy.uix.treeview import TreeView
-# from kivy.uix.treeview import TreeViewLabel
-# from kivy.uix.treeview import TreeViewNode
-# from kivy.uix.label import Label
-# from kivy.uix.button import Button
-# from kivy.uix.behaviors import ButtonBehavior
-# from kivy.uix.scrollview import ScrollView
-
-# from kivy.clock import Clock
+from kivy.event import EventDispatcher
 from kivy.properties import BooleanProperty
 from kivy.properties import NumericProperty
 from kivy.properties import StringProperty
 
-from kivy.event import EventDispatcher
+from pysollib.gamedb import GI
+from pysollib.kivy.LApp import LMenu
+from pysollib.kivy.LApp import LMenuItem
+from pysollib.kivy.LApp import LScrollView
+from pysollib.kivy.LApp import LTopLevel
+from pysollib.kivy.LApp import LTreeNode
+from pysollib.kivy.LApp import LTreeRoot
+from pysollib.kivy.findcarddialog import destroy_find_card_dialog
+from pysollib.kivy.selectcardset import SelectCardsetDialogWithPreview
+from pysollib.kivy.selectgame import SelectGameDialog
+from pysollib.kivy.solverdialog import connect_game_solver_dialog
+from pysollib.kivy.tkconst import CURSOR_WATCH, EVENT_HANDLED, EVENT_PROPAGATE
+from pysollib.kivy.tkconst import TOOLBAR_BUTTONS
+from pysollib.kivy.tkutil import after_idle
+from pysollib.kivy.tkutil import bind
+from pysollib.mfxutil import Struct
+from pysollib.mygettext import _
+from pysollib.pysoltk import connect_game_find_card_dialog
+from pysollib.settings import SELECT_GAME_MENU
+from pysollib.settings import TITLE
+from pysollib.util import CARDSET
 
-from LApp import LMenu
-from LApp import LTreeNode
-from LApp import LMenuItem
-from LApp import LTopLevel
-from LApp import LScrollView
-from LApp import LTreeRoot
-
-
-__all__ = ['PysolMenubarTk']
 
 # ************************************************************************
 # * tk emuls:
@@ -814,9 +782,9 @@ class OptionsMenuDialog(LMenuDialog):
                             self.menubar.tkopt.cardbacks[i], bi,
                             self.make_vars_command(
                                 self.menubar.mOptSetCardback, i))
-                        bi = bi + 1
+                        bi += 1
 
-                i = i + 1
+                i += 1
 
         # -------------------------------------------
         # Table background settings
@@ -866,7 +834,7 @@ class OptionsMenuDialog(LMenuDialog):
                 tm = self.app.tabletile_manager
                 # cnt = tm.len()
                 i = 1
-                while 1:
+                while True:
                     ti = tm.get(i)
                     if ti is None:
                         break
@@ -874,7 +842,7 @@ class OptionsMenuDialog(LMenuDialog):
                                       ti.name,
                                       self.menubar.tkopt.tabletile, i,
                                       self.menubar.mOptTileSet)
-                    i = i + 1
+                    i += 1
 
         # -------------------------------------------
         # Card view options
@@ -963,12 +931,12 @@ class OptionsMenuDialog(LMenuDialog):
         if rg:
             self.addRadioNode(tv, rg,
                               'Drag-and-Drop',
-                              self.menubar.tkopt.mouse_type, u'drag-n-drop',
+                              self.menubar.tkopt.mouse_type, 'drag-n-drop',
                               self.menubar.mOptMouseType)
 
             self.addRadioNode(tv, rg,
                               'Point-and-Click',
-                              self.menubar.tkopt.mouse_type, u'point-n-click',
+                              self.menubar.tkopt.mouse_type, 'point-n-click',
                               self.menubar.mOptMouseType)
 
             # sinnlos mit touch-device:
@@ -1069,30 +1037,43 @@ class OptionsMenuDialog(LMenuDialog):
                           self.menubar.tkopt.display_win_message,
                           self.menubar.mWinDialog)
 
+
 # ************************************************************************
 
 
 class HelpMenuDialog(LMenuDialog):
-
     def __init__(self, menubar, parent, title, app, **kw):
         kw['size_hint'] = (0.3, 1)
         kw['persist'] = True
-        super(HelpMenuDialog, self).__init__(
-            menubar, parent, title, app, **kw)
+        super(HelpMenuDialog, self).__init__(menubar, parent, title, app, **kw)
+
+    def make_help_command(self, command):
+        def help_command():
+            command()
+            self.closeWindow(0)
+        return help_command
 
     def buildTree(self, tv, node):
-        tv.add_node(LTreeNode(
-            text='Contents', command=self.menubar.mHelp))
-
-        tv.add_node(LTreeNode(
-            text='How to play', command=self.menubar.mHelpHowToPlay))
-        tv.add_node(LTreeNode(
-            text='Rules for this game', command=self.menubar.mHelpRules))
-        tv.add_node(LTreeNode(
-            text='License terms', command=self.menubar.mHelpLicense))
-
-        tv.add_node(LTreeNode(
-            text='About' + TITLE + '...', command=self.menubar.mHelpAbout))
+        tv.add_node(
+            LTreeNode(
+                text='Contents',
+                command=self.make_help_command(self.menubar.mHelp)))
+        tv.add_node(
+            LTreeNode(
+                text='How to play',
+                command=self.make_help_command(self.menubar.mHelpHowToPlay)))
+        tv.add_node(
+            LTreeNode(
+                text='Rules for this game',
+                command=self.make_help_command(self.menubar.mHelpRules)))
+        tv.add_node(
+            LTreeNode(
+                text='License terms',
+                command=self.make_help_command(self.menubar.mHelpLicense)))
+        tv.add_node(
+            LTreeNode(
+                text='About' + TITLE + '...',
+                command=self.make_help_command(self.menubar.mHelpAbout)))
 
         # tv.add_node(LTreeNode(
         #   text='AboutKivy ...',
@@ -1101,8 +1082,10 @@ class HelpMenuDialog(LMenuDialog):
     def makeHtmlCommand(self, bar, htmlfile):
         def htmlCommand():
             bar.mHelpHtml(htmlfile)
+
         return htmlCommand
 
+
 # ************************************************************************
 # *
 # ************************************************************************
@@ -1112,9 +1095,6 @@ class EmulTkMenu(object):
 
     def __init__(self, master, **kw):
 
-        # tearoff = 0
-        # self.n = kw["tearoff"] = int(kw.get("tearoff", tearoff))
-
         self.name = kw["name"]
         self.n = 0
         self._w = None
@@ -1126,10 +1106,7 @@ class EmulTkMenu(object):
         else:
             self.name = "<>"
 
-        # print('self._w = %s' % self._w)
-
     def labeltoname(self, label):
-        # print label, type(label)
         name = re.sub(r"[^0-9a-zA-Z]", "", label).lower()
         label = _(label)
         underline = label.find('&')
@@ -1138,19 +1115,14 @@ class EmulTkMenu(object):
         return name, label, underline
 
     def add_cascade(self, cnf={}, **kw):
-        # print('add_cascade: %s, %s' % (cnf, kw))
         self.add('cascade', cnf or kw)
         pass
 
     def add(self, itemType, cnf={}):
         label = cnf.get("label")
-        # print('add: label=%s' % label)
         if label:
             name = cnf.get('name')
             if name:
-                # LB ?????
-                #   del cnf['name'] # TclError: unknown option "-name"
-                # else:
                 name, label, underline = self.labeltoname(label)
                 cnf["underline"] = cnf.get("underline", underline)
                 cnf["label"] = label
@@ -1158,9 +1130,6 @@ class EmulTkMenu(object):
                     path = str(self._w) + "." + name
                     self.addPath(path, self, self.n, cnf.get("menu"))
 
-        # Tkinter.Menu.add(self, itemType, cnf)
-        # self.n = self.n + 1
-
     def cget(self, key):
         return key
 
