@@ -21,40 +21,39 @@
 #
 # ---------------------------------------------------------------------------##
 
-# imports
-import sys
-import os
-import time
 import locale
+import os
+import re
+import sys
+import time
 import webbrowser
-from six import print_
-
-from pickle import Pickler, Unpickler, UnpicklingError
+from pickle import Pickler, Unpickler
 
 from pysollib.settings import PACKAGE, TOOLKIT
 
+import six
+from six import print_
+
 Image = ImageTk = ImageOps = None
 if TOOLKIT == 'tk':
     try:  # PIL
         from PIL import Image
-        from PIL import ImageTk
-        from PIL import ImageOps
+        from PIL import ImageTk  # noqa: F401
+        from PIL import ImageOps  # noqa: F401
     except ImportError:
         Image = None
     else:
         # for py2exe
-        from PIL import GifImagePlugin
-        from PIL import PngImagePlugin
-        from PIL import JpegImagePlugin
-        from PIL import BmpImagePlugin
-        from PIL import PpmImagePlugin
+        from PIL import GifImagePlugin  # noqa: F401
+        from PIL import PngImagePlugin  # noqa: F401
+        from PIL import JpegImagePlugin  # noqa: F401
+        from PIL import BmpImagePlugin  # noqa: F401
+        from PIL import PpmImagePlugin  # noqa: F401
         Image._initialized = 2
 USE_PIL = False
-if TOOLKIT == 'tk' and Image and Image.VERSION >= '1.1.7':
+if TOOLKIT == 'tk' and Image:
     USE_PIL = True
 
-if sys.version_info > (3,):
-    unicode = str
 # debug
 # Image = None
 # USE_PIL = False
@@ -79,13 +78,16 @@ def latin1_to_ascii(n):
     # return n
     n = n.encode('iso8859-1', 'replace')
     # FIXME: rewrite this for better speed
-    n = (n.replace("\xc4", "Ae")
-         .replace("\xd6", "Oe")
-         .replace("\xdc", "Ue")
-         .replace("\xe4", "ae")
-         .replace("\xf6", "oe")
-         .replace("\xfc", "ue"))
-    return n
+    return (n.replace("\xc4", "Ae")
+             .replace("\xd6", "Oe")
+             .replace("\xdc", "Ue")
+             .replace("\xe4", "ae")
+             .replace("\xf6", "oe")
+             .replace("\xfc", "ue"))
+
+
+def latin1_normalize(n):
+    return re.sub(r"[^\w]", "", latin1_to_ascii(n).lower())
 
 
 def format_time(t):
@@ -127,10 +129,10 @@ def getusername():
 def getprefdir(package):
 
     if (TOOLKIT == 'kivy'):
-      from kivy.LApp import get_platform
-      plat = get_platform()
-      if plat == 'android':
-         os.environ['HOME'] = '/sdcard'
+        from pysollib.kivy.LApp import get_platform
+        plat = get_platform()
+        if plat == 'android':
+            os.environ['HOME'] = '/sdcard'
 
     if os.name == "nt":
         return win32_getprefdir(package)
@@ -141,7 +143,7 @@ def getprefdir(package):
 
 
 # high resolution clock() and sleep()
-uclock = time.clock
+uclock = time.time
 usleep = time.sleep
 if os.name == "posix":
     uclock = time.time
@@ -154,7 +156,7 @@ if os.name == "posix":
 def win32_getusername():
     user = os.environ.get('USERNAME', '').strip()
     try:
-        user = unicode(user, locale.getpreferredencoding())
+        user = six.text_type(user, locale.getpreferredencoding())
     except Exception:
         user = ''
     return user
@@ -180,7 +182,8 @@ def win32_getprefdir(package):
 # ************************************************************************
 
 def destruct(obj):
-    if TOOLKIT=='kivy': return
+    if TOOLKIT == 'kivy':
+        return
 
     # assist in breaking circular references
     if obj is not None:
@@ -281,8 +284,7 @@ def pickle(obj, filename, protocol=0):
     f = None
     try:
         f = open(filename, "wb")
-        p = Pickler(f, protocol)
-        p.dump(obj)
+        Pickler(f, protocol).dump(obj)
         f.close()
         f = None
         # print "Pickled", filename
@@ -295,8 +297,7 @@ def unpickle(filename):
     f, obj = None, None
     try:
         f = open(filename, "rb")
-        p = Unpickler(f)
-        x = p.load()
+        x = Unpickler(f).load()
         f.close()
         f = None
         obj = x
@@ -312,4 +313,10 @@ def unpickle(filename):
 # ************************************************************************
 
 def openURL(url):
-    thread.start_new_thread(webbrowser.open, (url,))
+    try:
+        webbrowser.open(url)
+    except OSError:                  # raised on windows if link is unreadable
+        pass
+    except Exception:
+        return False
+    return True
